
'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/query/v1beta1/pagination.proto\x12\x19cosmos.base.query.v1beta1"_\n\x0bPageRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x13\n\x0bcount_total\x18\x04 \x01(\x08\x12\x0f\n\x07reverse\x18\x05 \x01(\x08"/\n\x0cPageResponse\x12\x10\n\x08next_key\x18\x01 \x01(\x0c\x12\r\n\x05total\x18\x02 \x01(\x04B*Z(github.com/cosmos/cosmos-sdk/types/queryb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.query.v1beta1.pagination_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/types/query'
    _PAGEREQUEST._serialized_start = 73
    _PAGEREQUEST._serialized_end = 168
    _PAGERESPONSE._serialized_start = 170
    _PAGERESPONSE._serialized_end = 217




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....sentinel.node.v2 import querier_pb2 as sentinel_dot_node_dot_v2_dot_querier__pb2

class QueryServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.QueryNodes = channel.unary_unary('/sentinel.node.v2.QueryService/QueryNodes', request_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesRequest.SerializeToString, response_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesResponse.FromString)
        self.QueryNodesForPlan = channel.unary_unary('/sentinel.node.v2.QueryService/QueryNodesForPlan', request_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesForPlanRequest.SerializeToString, response_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesForPlanResponse.FromString)
        self.QueryNode = channel.unary_unary('/sentinel.node.v2.QueryService/QueryNode', request_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodeRequest.SerializeToString, response_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodeResponse.FromString)
        self.QueryParams = channel.unary_unary('/sentinel.node.v2.QueryService/QueryParams', request_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryParamsRequest.SerializeToString, response_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryParamsResponse.FromString)

class QueryServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def QueryNodes(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryNodesForPlan(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryNode(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryParams(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'QueryNodes': grpc.unary_unary_rpc_method_handler(servicer.QueryNodes, request_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesRequest.FromString, response_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesResponse.SerializeToString), 'QueryNodesForPlan': grpc.unary_unary_rpc_method_handler(servicer.QueryNodesForPlan, request_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesForPlanRequest.FromString, response_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesForPlanResponse.SerializeToString), 'QueryNode': grpc.unary_unary_rpc_method_handler(servicer.QueryNode, request_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodeRequest.FromString, response_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodeResponse.SerializeToString), 'QueryParams': grpc.unary_unary_rpc_method_handler(servicer.QueryParams, request_deserializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryParamsRequest.FromString, response_serializer=sentinel_dot_node_dot_v2_dot_querier__pb2.QueryParamsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('sentinel.node.v2.QueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class QueryService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def QueryNodes(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.node.v2.QueryService/QueryNodes', sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesRequest.SerializeToString, sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryNodesForPlan(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.node.v2.QueryService/QueryNodesForPlan', sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesForPlanRequest.SerializeToString, sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodesForPlanResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryNode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.node.v2.QueryService/QueryNode', sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodeRequest.SerializeToString, sentinel_dot_node_dot_v2_dot_querier__pb2.QueryNodeResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryParams(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.node.v2.QueryService/QueryParams', sentinel_dot_node_dot_v2_dot_querier__pb2.QueryParamsRequest.SerializeToString, sentinel_dot_node_dot_v2_dot_querier__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/bank/v1beta1/query.proto\x12\x13cosmos.bank.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1ecosmos/bank/v1beta1/bank.proto"?\n\x13QueryBalanceRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12\r\n\x05denom\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"B\n\x14QueryBalanceResponse\x12*\n\x07balance\x18\x01 \x01(\x0b2\x19.cosmos.base.v1beta1.Coin"p\n\x17QueryAllBalancesRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xb6\x01\n\x18QueryAllBalancesResponse\x12]\n\x08balances\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"v\n\x1dQuerySpendableBalancesRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xbc\x01\n\x1eQuerySpendableBalancesResponse\x12]\n\x08balances\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"_\n\x17QueryTotalSupplyRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xb4\x01\n\x18QueryTotalSupplyResponse\x12[\n\x06supply\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"%\n\x14QuerySupplyOfRequest\x12\r\n\x05denom\x18\x01 \x01(\t"H\n\x15QuerySupplyOfResponse\x12/\n\x06amount\x18\x01 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00"\x14\n\x12QueryParamsRequest"H\n\x13QueryParamsResponse\x121\n\x06params\x18\x01 \x01(\x0b2\x1b.cosmos.bank.v1beta1.ParamsB\x04\xc8\xde\x1f\x00"X\n\x1aQueryDenomsMetadataRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x92\x01\n\x1bQueryDenomsMetadataResponse\x126\n\tmetadatas\x18\x01 \x03(\x0b2\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"*\n\x19QueryDenomMetadataRequest\x12\r\n\x05denom\x18\x01 \x01(\t"S\n\x1aQueryDenomMetadataResponse\x125\n\x08metadata\x18\x01 \x01(\x0b2\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x002\xed\t\n\x05Query\x12\x98\x01\n\x07Balance\x12(.cosmos.bank.v1beta1.QueryBalanceRequest\x1a).cosmos.bank.v1beta1.QueryBalanceResponse"8\x82\xd3\xe4\x93\x022\x120/cosmos/bank/v1beta1/balances/{address}/by_denom\x12\x9b\x01\n\x0bAllBalances\x12,.cosmos.bank.v1beta1.QueryAllBalancesRequest\x1a-.cosmos.bank.v1beta1.QueryAllBalancesResponse"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/bank/v1beta1/balances/{address}\x12\xb7\x01\n\x11SpendableBalances\x122.cosmos.bank.v1beta1.QuerySpendableBalancesRequest\x1a3.cosmos.bank.v1beta1.QuerySpendableBalancesResponse"9\x82\xd3\xe4\x93\x023\x121/cosmos/bank/v1beta1/spendable_balances/{address}\x12\x8f\x01\n\x0bTotalSupply\x12,.cosmos.bank.v1beta1.QueryTotalSupplyRequest\x1a-.cosmos.bank.v1beta1.QueryTotalSupplyResponse"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/supply\x12\x8e\x01\n\x08SupplyOf\x12).cosmos.bank.v1beta1.QuerySupplyOfRequest\x1a*.cosmos.bank.v1beta1.QuerySupplyOfResponse"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/bank/v1beta1/supply/{denom}\x12\x80\x01\n\x06Params\x12\'.cosmos.bank.v1beta1.QueryParamsRequest\x1a(.cosmos.bank.v1beta1.QueryParamsResponse"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/params\x12\xa6\x01\n\rDenomMetadata\x12..cosmos.bank.v1beta1.QueryDenomMetadataRequest\x1a/.cosmos.bank.v1beta1.QueryDenomMetadataResponse"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/bank/v1beta1/denoms_metadata/{denom}\x12\xa1\x01\n\x0eDenomsMetadata\x12/.cosmos.bank.v1beta1.QueryDenomsMetadataRequest\x1a0.cosmos.bank.v1beta1.QueryDenomsMetadataResponse",\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/denoms_metadataB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
    _QUERYBALANCEREQUEST._options = None
    _QUERYBALANCEREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYALLBALANCESREQUEST._options = None
    _QUERYALLBALANCESREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYALLBALANCESRESPONSE.fields_by_name['balances']._options = None
    _QUERYALLBALANCESRESPONSE.fields_by_name['balances']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _QUERYSPENDABLEBALANCESREQUEST._options = None
    _QUERYSPENDABLEBALANCESREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYSPENDABLEBALANCESRESPONSE.fields_by_name['balances']._options = None
    _QUERYSPENDABLEBALANCESRESPONSE.fields_by_name['balances']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _QUERYTOTALSUPPLYREQUEST._options = None
    _QUERYTOTALSUPPLYREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYTOTALSUPPLYRESPONSE.fields_by_name['supply']._options = None
    _QUERYTOTALSUPPLYRESPONSE.fields_by_name['supply']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _QUERYSUPPLYOFRESPONSE.fields_by_name['amount']._options = None
    _QUERYSUPPLYOFRESPONSE.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDENOMSMETADATARESPONSE.fields_by_name['metadatas']._options = None
    _QUERYDENOMSMETADATARESPONSE.fields_by_name['metadatas']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDENOMMETADATARESPONSE.fields_by_name['metadata']._options = None
    _QUERYDENOMMETADATARESPONSE.fields_by_name['metadata']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Balance']._options = None
    _QUERY.methods_by_name['Balance']._serialized_options = b'\x82\xd3\xe4\x93\x022\x120/cosmos/bank/v1beta1/balances/{address}/by_denom'
    _QUERY.methods_by_name['AllBalances']._options = None
    _QUERY.methods_by_name['AllBalances']._serialized_options = b"\x82\xd3\xe4\x93\x02)\x12'/cosmos/bank/v1beta1/balances/{address}"
    _QUERY.methods_by_name['SpendableBalances']._options = None
    _QUERY.methods_by_name['SpendableBalances']._serialized_options = b'\x82\xd3\xe4\x93\x023\x121/cosmos/bank/v1beta1/spendable_balances/{address}'
    _QUERY.methods_by_name['TotalSupply']._options = None
    _QUERY.methods_by_name['TotalSupply']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/supply'
    _QUERY.methods_by_name['SupplyOf']._options = None
    _QUERY.methods_by_name['SupplyOf']._serialized_options = b'\x82\xd3\xe4\x93\x02%\x12#/cosmos/bank/v1beta1/supply/{denom}'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/params'
    _QUERY.methods_by_name['DenomMetadata']._options = None
    _QUERY.methods_by_name['DenomMetadata']._serialized_options = b'\x82\xd3\xe4\x93\x02.\x12,/cosmos/bank/v1beta1/denoms_metadata/{denom}'
    _QUERY.methods_by_name['DenomsMetadata']._options = None
    _QUERY.methods_by_name['DenomsMetadata']._serialized_options = b'\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/denoms_metadata'
    _QUERYBALANCEREQUEST._serialized_start = 216
    _QUERYBALANCEREQUEST._serialized_end = 279
    _QUERYBALANCERESPONSE._serialized_start = 281
    _QUERYBALANCERESPONSE._serialized_end = 347
    _QUERYALLBALANCESREQUEST._serialized_start = 349
    _QUERYALLBALANCESREQUEST._serialized_end = 461
    _QUERYALLBALANCESRESPONSE._serialized_start = 464
    _QUERYALLBALANCESRESPONSE._serialized_end = 646
    _QUERYSPENDABLEBALANCESREQUEST._serialized_start = 648
    _QUERYSPENDABLEBALANCESREQUEST._serialized_end = 766
    _QUERYSPENDABLEBALANCESRESPONSE._serialized_start = 769
    _QUERYSPENDABLEBALANCESRESPONSE._serialized_end = 957
    _QUERYTOTALSUPPLYREQUEST._serialized_start = 959
    _QUERYTOTALSUPPLYREQUEST._serialized_end = 1054
    _QUERYTOTALSUPPLYRESPONSE._serialized_start = 1057
    _QUERYTOTALSUPPLYRESPONSE._serialized_end = 1237
    _QUERYSUPPLYOFREQUEST._serialized_start = 1239
    _QUERYSUPPLYOFREQUEST._serialized_end = 1276
    _QUERYSUPPLYOFRESPONSE._serialized_start = 1278
    _QUERYSUPPLYOFRESPONSE._serialized_end = 1350
    _QUERYPARAMSREQUEST._serialized_start = 1352
    _QUERYPARAMSREQUEST._serialized_end = 1372
    _QUERYPARAMSRESPONSE._serialized_start = 1374
    _QUERYPARAMSRESPONSE._serialized_end = 1446
    _QUERYDENOMSMETADATAREQUEST._serialized_start = 1448
    _QUERYDENOMSMETADATAREQUEST._serialized_end = 1536
    _QUERYDENOMSMETADATARESPONSE._serialized_start = 1539
    _QUERYDENOMSMETADATARESPONSE._serialized_end = 1685
    _QUERYDENOMMETADATAREQUEST._serialized_start = 1687
    _QUERYDENOMMETADATAREQUEST._serialized_end = 1729
    _QUERYDENOMMETADATARESPONSE._serialized_start = 1731
    _QUERYDENOMMETADATARESPONSE._serialized_end = 1814
    _QUERY._serialized_start = 1817
    _QUERY._serialized_end = 3078




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/capability/v1beta1/capability.proto\x12\x19cosmos.capability.v1beta1\x1a\x14gogoproto/gogo.proto"3\n\nCapability\x12\x1f\n\x05index\x18\x01 \x01(\x04B\x10\xf2\xde\x1f\x0cyaml:"index":\x04\x98\xa0\x1f\x00"S\n\x05Owner\x12!\n\x06module\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:"module"\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:"name":\x08\x98\xa0\x1f\x00\x88\xa0\x1f\x00"J\n\x10CapabilityOwners\x126\n\x06owners\x18\x01 \x03(\x0b2 .cosmos.capability.v1beta1.OwnerB\x04\xc8\xde\x1f\x00B1Z/github.com/cosmos/cosmos-sdk/x/capability/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.capability.v1beta1.capability_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z/github.com/cosmos/cosmos-sdk/x/capability/types'
    _CAPABILITY.fields_by_name['index']._options = None
    _CAPABILITY.fields_by_name['index']._serialized_options = b'\xf2\xde\x1f\x0cyaml:"index"'
    _CAPABILITY._options = None
    _CAPABILITY._serialized_options = b'\x98\xa0\x1f\x00'
    _OWNER.fields_by_name['module']._options = None
    _OWNER.fields_by_name['module']._serialized_options = b'\xf2\xde\x1f\ryaml:"module"'
    _OWNER.fields_by_name['name']._options = None
    _OWNER.fields_by_name['name']._serialized_options = b'\xf2\xde\x1f\x0byaml:"name"'
    _OWNER._options = None
    _OWNER._serialized_options = b'\x98\xa0\x1f\x00\x88\xa0\x1f\x00'
    _CAPABILITYOWNERS.fields_by_name['owners']._options = None
    _CAPABILITYOWNERS.fields_by_name['owners']._serialized_options = b'\xc8\xde\x1f\x00'
    _CAPABILITY._serialized_start = 95
    _CAPABILITY._serialized_end = 146
    _OWNER._serialized_start = 148
    _OWNER._serialized_end = 231
    _CAPABILITYOWNERS._serialized_start = 233
    _CAPABILITYOWNERS._serialized_end = 307




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/feegrant/v1beta1/feegrant.proto\x12\x17cosmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto"\xbb\x01\n\x0eBasicAllowance\x12`\n\x0bspend_limit\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x124\n\nexpiration\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01:\x11\xca\xb4-\rFeeAllowanceI"\xa5\x03\n\x11PeriodicAllowance\x12<\n\x05basic\x18\x01 \x01(\x0b2\'.cosmos.feegrant.v1beta1.BasicAllowanceB\x04\xc8\xde\x1f\x00\x123\n\x06period\x18\x02 \x01(\x0b2\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12g\n\x12period_spend_limit\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12e\n\x10period_can_spend\x18\x04 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12:\n\x0cperiod_reset\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00:\x11\xca\xb4-\rFeeAllowanceI"\x82\x01\n\x13AllowedMsgAllowance\x12:\n\tallowance\x18\x01 \x01(\x0b2\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceI\x12\x18\n\x10allowed_messages\x18\x02 \x03(\t:\x15\x88\xa0\x1f\x00\xca\xb4-\rFeeAllowanceI"e\n\x05Grant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12:\n\tallowance\x18\x03 \x01(\x0b2\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceIB)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.feegrant_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z'github.com/cosmos/cosmos-sdk/x/feegrant"
    _BASICALLOWANCE.fields_by_name['spend_limit']._options = None
    _BASICALLOWANCE.fields_by_name['spend_limit']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _BASICALLOWANCE.fields_by_name['expiration']._options = None
    _BASICALLOWANCE.fields_by_name['expiration']._serialized_options = b'\x90\xdf\x1f\x01'
    _BASICALLOWANCE._options = None
    _BASICALLOWANCE._serialized_options = b'\xca\xb4-\rFeeAllowanceI'
    _PERIODICALLOWANCE.fields_by_name['basic']._options = None
    _PERIODICALLOWANCE.fields_by_name['basic']._serialized_options = b'\xc8\xde\x1f\x00'
    _PERIODICALLOWANCE.fields_by_name['period']._options = None
    _PERIODICALLOWANCE.fields_by_name['period']._serialized_options = b'\x98\xdf\x1f\x01\xc8\xde\x1f\x00'
    _PERIODICALLOWANCE.fields_by_name['period_spend_limit']._options = None
    _PERIODICALLOWANCE.fields_by_name['period_spend_limit']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PERIODICALLOWANCE.fields_by_name['period_can_spend']._options = None
    _PERIODICALLOWANCE.fields_by_name['period_can_spend']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PERIODICALLOWANCE.fields_by_name['period_reset']._options = None
    _PERIODICALLOWANCE.fields_by_name['period_reset']._serialized_options = b'\x90\xdf\x1f\x01\xc8\xde\x1f\x00'
    _PERIODICALLOWANCE._options = None
    _PERIODICALLOWANCE._serialized_options = b'\xca\xb4-\rFeeAllowanceI'
    _ALLOWEDMSGALLOWANCE.fields_by_name['allowance']._options = None
    _ALLOWEDMSGALLOWANCE.fields_by_name['allowance']._serialized_options = b'\xca\xb4-\rFeeAllowanceI'
    _ALLOWEDMSGALLOWANCE._options = None
    _ALLOWEDMSGALLOWANCE._serialized_options = b'\x88\xa0\x1f\x00\xca\xb4-\rFeeAllowanceI'
    _GRANT.fields_by_name['allowance']._options = None
    _GRANT.fields_by_name['allowance']._serialized_options = b'\xca\xb4-\rFeeAllowanceI'
    _BASICALLOWANCE._serialized_start = 241
    _BASICALLOWANCE._serialized_end = 428
    _PERIODICALLOWANCE._serialized_start = 431
    _PERIODICALLOWANCE._serialized_end = 852
    _ALLOWEDMSGALLOWANCE._serialized_start = 855
    _ALLOWEDMSGALLOWANCE._serialized_end = 985
    _GRANT._serialized_start = 987
    _GRANT._serialized_end = 1088




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/staking.proto\x12\x16cosmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1ctendermint/types/types.proto"y\n\x0eHistoricalInfo\x12.\n\x06header\x18\x01 \x01(\x0b2\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x127\n\x06valset\x18\x02 \x03(\x0b2!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00"\x91\x02\n\x0fCommissionRates\x12<\n\x04rate\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12S\n\x08max_rate\x18\x02 \x01(\tBA\xf2\xde\x1f\x0fyaml:"max_rate"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12a\n\x0fmax_change_rate\x18\x03 \x01(\tBH\xf2\xde\x1f\x16yaml:"max_change_rate"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\xb4\x01\n\nCommission\x12K\n\x10commission_rates\x18\x01 \x01(\x0b2\'.cosmos.staking.v1beta1.CommissionRatesB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x12O\n\x0bupdate_time\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB\x1e\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x12yaml:"update_time":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\x93\x01\n\x0bDescription\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x125\n\x10security_contact\x18\x04 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"security_contact"\x12\x0f\n\x07details\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\x95\x06\n\tValidator\x125\n\x10operator_address\x18\x01 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"operator_address"\x12c\n\x10consensus_pubkey\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB3\xca\xb4-\x14cosmos.crypto.PubKey\xf2\xde\x1f\x17yaml:"consensus_pubkey"\x12\x0e\n\x06jailed\x18\x03 \x01(\x08\x122\n\x06status\x18\x04 \x01(\x0e2".cosmos.staking.v1beta1.BondStatus\x12>\n\x06tokens\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12c\n\x10delegator_shares\x18\x06 \x01(\tBI\xf2\xde\x1f\x17yaml:"delegator_shares"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x0bdescription\x18\x07 \x01(\x0b2#.cosmos.staking.v1beta1.DescriptionB\x04\xc8\xde\x1f\x00\x125\n\x10unbonding_height\x18\x08 \x01(\x03B\x1b\xf2\xde\x1f\x17yaml:"unbonding_height"\x12U\n\x0eunbonding_time\x18\t \x01(\x0b2\x1a.google.protobuf.TimestampB!\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x15yaml:"unbonding_time"\x12<\n\ncommission\x18\n \x01(\x0b2".cosmos.staking.v1beta1.CommissionB\x04\xc8\xde\x1f\x00\x12i\n\x13min_self_delegation\x18\x0b \x01(\tBL\xf2\xde\x1f\x1ayaml:"min_self_delegation"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x88\xa0\x1f\x00"+\n\x0cValAddresses\x12\x11\n\taddresses\x18\x01 \x03(\t:\x08\x98\xa0\x1f\x00\x80\xdc \x01"\x88\x01\n\x06DVPair\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address":\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00">\n\x07DVPairs\x123\n\x05pairs\x18\x01 \x03(\x0b2\x1e.cosmos.staking.v1beta1.DVPairB\x04\xc8\xde\x1f\x00"\xd5\x01\n\nDVVTriplet\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x12?\n\x15validator_src_address\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:"validator_src_address"\x12?\n\x15validator_dst_address\x18\x03 \x01(\tB \xf2\xde\x1f\x1cyaml:"validator_dst_address":\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00"I\n\x0bDVVTriplets\x12:\n\x08triplets\x18\x01 \x03(\x0b2".cosmos.staking.v1beta1.DVVTripletB\x04\xc8\xde\x1f\x00"\xcc\x01\n\nDelegation\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12>\n\x06shares\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00"\xde\x01\n\x13UnbondingDelegation\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12G\n\x07entries\x18\x03 \x03(\x0b20.cosmos.staking.v1beta1.UnbondingDelegationEntryB\x04\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00"\xd6\x02\n\x18UnbondingDelegationEntry\x123\n\x0fcreation_height\x18\x01 \x01(\x03B\x1a\xf2\xde\x1f\x16yaml:"creation_height"\x12W\n\x0fcompletion_time\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB"\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:"completion_time"\x12a\n\x0finitial_balance\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"initial_balance"\x12?\n\x07balance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\xd2\x02\n\x11RedelegationEntry\x123\n\x0fcreation_height\x18\x01 \x01(\x03B\x1a\xf2\xde\x1f\x16yaml:"creation_height"\x12W\n\x0fcompletion_time\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB"\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:"completion_time"\x12a\n\x0finitial_balance\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"initial_balance"\x12B\n\nshares_dst\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\x99\x02\n\x0cRedelegation\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x12?\n\x15validator_src_address\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:"validator_src_address"\x12?\n\x15validator_dst_address\x18\x03 \x01(\tB \xf2\xde\x1f\x1cyaml:"validator_dst_address"\x12@\n\x07entries\x18\x04 \x03(\x0b2).cosmos.staking.v1beta1.RedelegationEntryB\x04\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00"\xae\x02\n\x06Params\x12T\n\x0eunbonding_time\x18\x01 \x01(\x0b2\x19.google.protobuf.DurationB!\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x15yaml:"unbonding_time"\x121\n\x0emax_validators\x18\x02 \x01(\rB\x19\xf2\xde\x1f\x15yaml:"max_validators"\x12+\n\x0bmax_entries\x18\x03 \x01(\rB\x16\xf2\xde\x1f\x12yaml:"max_entries"\x129\n\x12historical_entries\x18\x04 \x01(\rB\x1d\xf2\xde\x1f\x19yaml:"historical_entries"\x12)\n\nbond_denom\x18\x05 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"bond_denom":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\x8e\x01\n\x12DelegationResponse\x12<\n\ndelegation\x18\x01 \x01(\x0b2".cosmos.staking.v1beta1.DelegationB\x04\xc8\xde\x1f\x00\x120\n\x07balance\x18\x02 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x98\xa0\x1f\x00"\xaf\x01\n\x19RedelegationEntryResponse\x12K\n\x12redelegation_entry\x18\x01 \x01(\x0b2).cosmos.staking.v1beta1.RedelegationEntryB\x04\xc8\xde\x1f\x00\x12?\n\x07balance\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01"\xa8\x01\n\x14RedelegationResponse\x12@\n\x0credelegation\x18\x01 \x01(\x0b2$.cosmos.staking.v1beta1.RedelegationB\x04\xc8\xde\x1f\x00\x12H\n\x07entries\x18\x02 \x03(\x0b21.cosmos.staking.v1beta1.RedelegationEntryResponseB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x00"\xe0\x01\n\x04Pool\x12^\n\x11not_bonded_tokens\x18\x01 \x01(\tBC\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xea\xde\x1f\x11not_bonded_tokens\xc8\xde\x1f\x00\x12n\n\rbonded_tokens\x18\x02 \x01(\tBW\xea\xde\x1f\rbonded_tokens\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"bonded_tokens":\x08\xf0\xa0\x1f\x01\xe8\xa0\x1f\x01*\xb6\x01\n\nBondStatus\x12,\n\x17BOND_STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12&\n\x14BOND_STATUS_UNBONDED\x10\x01\x1a\x0c\x8a\x9d \x08Unbonded\x12(\n\x15BOND_STATUS_UNBONDING\x10\x02\x1a\r\x8a\x9d \tUnbonding\x12"\n\x12BOND_STATUS_BONDED\x10\x03\x1a\n\x8a\x9d \x06Bonded\x1a\x04\x88\xa3\x1e\x00B.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.staking_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
    _BONDSTATUS._options = None
    _BONDSTATUS._serialized_options = b'\x88\xa3\x1e\x00'
    _BONDSTATUS.values_by_name['BOND_STATUS_UNSPECIFIED']._options = None
    _BONDSTATUS.values_by_name['BOND_STATUS_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x0bUnspecified'
    _BONDSTATUS.values_by_name['BOND_STATUS_UNBONDED']._options = None
    _BONDSTATUS.values_by_name['BOND_STATUS_UNBONDED']._serialized_options = b'\x8a\x9d \x08Unbonded'
    _BONDSTATUS.values_by_name['BOND_STATUS_UNBONDING']._options = None
    _BONDSTATUS.values_by_name['BOND_STATUS_UNBONDING']._serialized_options = b'\x8a\x9d \tUnbonding'
    _BONDSTATUS.values_by_name['BOND_STATUS_BONDED']._options = None
    _BONDSTATUS.values_by_name['BOND_STATUS_BONDED']._serialized_options = b'\x8a\x9d \x06Bonded'
    _HISTORICALINFO.fields_by_name['header']._options = None
    _HISTORICALINFO.fields_by_name['header']._serialized_options = b'\xc8\xde\x1f\x00'
    _HISTORICALINFO.fields_by_name['valset']._options = None
    _HISTORICALINFO.fields_by_name['valset']._serialized_options = b'\xc8\xde\x1f\x00'
    _COMMISSIONRATES.fields_by_name['rate']._options = None
    _COMMISSIONRATES.fields_by_name['rate']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _COMMISSIONRATES.fields_by_name['max_rate']._options = None
    _COMMISSIONRATES.fields_by_name['max_rate']._serialized_options = b'\xf2\xde\x1f\x0fyaml:"max_rate"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _COMMISSIONRATES.fields_by_name['max_change_rate']._options = None
    _COMMISSIONRATES.fields_by_name['max_change_rate']._serialized_options = b'\xf2\xde\x1f\x16yaml:"max_change_rate"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _COMMISSIONRATES._options = None
    _COMMISSIONRATES._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _COMMISSION.fields_by_name['commission_rates']._options = None
    _COMMISSION.fields_by_name['commission_rates']._serialized_options = b'\xd0\xde\x1f\x01\xc8\xde\x1f\x00'
    _COMMISSION.fields_by_name['update_time']._options = None
    _COMMISSION.fields_by_name['update_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x12yaml:"update_time"'
    _COMMISSION._options = None
    _COMMISSION._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _DESCRIPTION.fields_by_name['security_contact']._options = None
    _DESCRIPTION.fields_by_name['security_contact']._serialized_options = b'\xf2\xde\x1f\x17yaml:"security_contact"'
    _DESCRIPTION._options = None
    _DESCRIPTION._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _VALIDATOR.fields_by_name['operator_address']._options = None
    _VALIDATOR.fields_by_name['operator_address']._serialized_options = b'\xf2\xde\x1f\x17yaml:"operator_address"'
    _VALIDATOR.fields_by_name['consensus_pubkey']._options = None
    _VALIDATOR.fields_by_name['consensus_pubkey']._serialized_options = b'\xca\xb4-\x14cosmos.crypto.PubKey\xf2\xde\x1f\x17yaml:"consensus_pubkey"'
    _VALIDATOR.fields_by_name['tokens']._options = None
    _VALIDATOR.fields_by_name['tokens']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _VALIDATOR.fields_by_name['delegator_shares']._options = None
    _VALIDATOR.fields_by_name['delegator_shares']._serialized_options = b'\xf2\xde\x1f\x17yaml:"delegator_shares"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _VALIDATOR.fields_by_name['description']._options = None
    _VALIDATOR.fields_by_name['description']._serialized_options = b'\xc8\xde\x1f\x00'
    _VALIDATOR.fields_by_name['unbonding_height']._options = None
    _VALIDATOR.fields_by_name['unbonding_height']._serialized_options = b'\xf2\xde\x1f\x17yaml:"unbonding_height"'
    _VALIDATOR.fields_by_name['unbonding_time']._options = None
    _VALIDATOR.fields_by_name['unbonding_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x15yaml:"unbonding_time"'
    _VALIDATOR.fields_by_name['commission']._options = None
    _VALIDATOR.fields_by_name['commission']._serialized_options = b'\xc8\xde\x1f\x00'
    _VALIDATOR.fields_by_name['min_self_delegation']._options = None
    _VALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\xf2\xde\x1f\x1ayaml:"min_self_delegation"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _VALIDATOR._options = None
    _VALIDATOR._serialized_options = b'\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x88\xa0\x1f\x00'
    _VALADDRESSES._options = None
    _VALADDRESSES._serialized_options = b'\x98\xa0\x1f\x00\x80\xdc \x01'
    _DVPAIR.fields_by_name['delegator_address']._options = None
    _DVPAIR.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _DVPAIR.fields_by_name['validator_address']._options = None
    _DVPAIR.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _DVPAIR._options = None
    _DVPAIR._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _DVPAIRS.fields_by_name['pairs']._options = None
    _DVPAIRS.fields_by_name['pairs']._serialized_options = b'\xc8\xde\x1f\x00'
    _DVVTRIPLET.fields_by_name['delegator_address']._options = None
    _DVVTRIPLET.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _DVVTRIPLET.fields_by_name['validator_src_address']._options = None
    _DVVTRIPLET.fields_by_name['validator_src_address']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"validator_src_address"'
    _DVVTRIPLET.fields_by_name['validator_dst_address']._options = None
    _DVVTRIPLET.fields_by_name['validator_dst_address']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"validator_dst_address"'
    _DVVTRIPLET._options = None
    _DVVTRIPLET._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _DVVTRIPLETS.fields_by_name['triplets']._options = None
    _DVVTRIPLETS.fields_by_name['triplets']._serialized_options = b'\xc8\xde\x1f\x00'
    _DELEGATION.fields_by_name['delegator_address']._options = None
    _DELEGATION.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _DELEGATION.fields_by_name['validator_address']._options = None
    _DELEGATION.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _DELEGATION.fields_by_name['shares']._options = None
    _DELEGATION.fields_by_name['shares']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _DELEGATION._options = None
    _DELEGATION._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _UNBONDINGDELEGATION.fields_by_name['delegator_address']._options = None
    _UNBONDINGDELEGATION.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _UNBONDINGDELEGATION.fields_by_name['validator_address']._options = None
    _UNBONDINGDELEGATION.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _UNBONDINGDELEGATION.fields_by_name['entries']._options = None
    _UNBONDINGDELEGATION.fields_by_name['entries']._serialized_options = b'\xc8\xde\x1f\x00'
    _UNBONDINGDELEGATION._options = None
    _UNBONDINGDELEGATION._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _UNBONDINGDELEGATIONENTRY.fields_by_name['creation_height']._options = None
    _UNBONDINGDELEGATIONENTRY.fields_by_name['creation_height']._serialized_options = b'\xf2\xde\x1f\x16yaml:"creation_height"'
    _UNBONDINGDELEGATIONENTRY.fields_by_name['completion_time']._options = None
    _UNBONDINGDELEGATIONENTRY.fields_by_name['completion_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:"completion_time"'
    _UNBONDINGDELEGATIONENTRY.fields_by_name['initial_balance']._options = None
    _UNBONDINGDELEGATIONENTRY.fields_by_name['initial_balance']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"initial_balance"'
    _UNBONDINGDELEGATIONENTRY.fields_by_name['balance']._options = None
    _UNBONDINGDELEGATIONENTRY.fields_by_name['balance']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _UNBONDINGDELEGATIONENTRY._options = None
    _UNBONDINGDELEGATIONENTRY._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _REDELEGATIONENTRY.fields_by_name['creation_height']._options = None
    _REDELEGATIONENTRY.fields_by_name['creation_height']._serialized_options = b'\xf2\xde\x1f\x16yaml:"creation_height"'
    _REDELEGATIONENTRY.fields_by_name['completion_time']._options = None
    _REDELEGATIONENTRY.fields_by_name['completion_time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:"completion_time"'
    _REDELEGATIONENTRY.fields_by_name['initial_balance']._options = None
    _REDELEGATIONENTRY.fields_by_name['initial_balance']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"initial_balance"'
    _REDELEGATIONENTRY.fields_by_name['shares_dst']._options = None
    _REDELEGATIONENTRY.fields_by_name['shares_dst']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _REDELEGATIONENTRY._options = None
    _REDELEGATIONENTRY._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _REDELEGATION.fields_by_name['delegator_address']._options = None
    _REDELEGATION.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _REDELEGATION.fields_by_name['validator_src_address']._options = None
    _REDELEGATION.fields_by_name['validator_src_address']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"validator_src_address"'
    _REDELEGATION.fields_by_name['validator_dst_address']._options = None
    _REDELEGATION.fields_by_name['validator_dst_address']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"validator_dst_address"'
    _REDELEGATION.fields_by_name['entries']._options = None
    _REDELEGATION.fields_by_name['entries']._serialized_options = b'\xc8\xde\x1f\x00'
    _REDELEGATION._options = None
    _REDELEGATION._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _PARAMS.fields_by_name['unbonding_time']._options = None
    _PARAMS.fields_by_name['unbonding_time']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x15yaml:"unbonding_time"'
    _PARAMS.fields_by_name['max_validators']._options = None
    _PARAMS.fields_by_name['max_validators']._serialized_options = b'\xf2\xde\x1f\x15yaml:"max_validators"'
    _PARAMS.fields_by_name['max_entries']._options = None
    _PARAMS.fields_by_name['max_entries']._serialized_options = b'\xf2\xde\x1f\x12yaml:"max_entries"'
    _PARAMS.fields_by_name['historical_entries']._options = None
    _PARAMS.fields_by_name['historical_entries']._serialized_options = b'\xf2\xde\x1f\x19yaml:"historical_entries"'
    _PARAMS.fields_by_name['bond_denom']._options = None
    _PARAMS.fields_by_name['bond_denom']._serialized_options = b'\xf2\xde\x1f\x11yaml:"bond_denom"'
    _PARAMS._options = None
    _PARAMS._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _DELEGATIONRESPONSE.fields_by_name['delegation']._options = None
    _DELEGATIONRESPONSE.fields_by_name['delegation']._serialized_options = b'\xc8\xde\x1f\x00'
    _DELEGATIONRESPONSE.fields_by_name['balance']._options = None
    _DELEGATIONRESPONSE.fields_by_name['balance']._serialized_options = b'\xc8\xde\x1f\x00'
    _DELEGATIONRESPONSE._options = None
    _DELEGATIONRESPONSE._serialized_options = b'\xe8\xa0\x1f\x00\x98\xa0\x1f\x00'
    _REDELEGATIONENTRYRESPONSE.fields_by_name['redelegation_entry']._options = None
    _REDELEGATIONENTRYRESPONSE.fields_by_name['redelegation_entry']._serialized_options = b'\xc8\xde\x1f\x00'
    _REDELEGATIONENTRYRESPONSE.fields_by_name['balance']._options = None
    _REDELEGATIONENTRYRESPONSE.fields_by_name['balance']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _REDELEGATIONENTRYRESPONSE._options = None
    _REDELEGATIONENTRYRESPONSE._serialized_options = b'\xe8\xa0\x1f\x01'
    _REDELEGATIONRESPONSE.fields_by_name['redelegation']._options = None
    _REDELEGATIONRESPONSE.fields_by_name['redelegation']._serialized_options = b'\xc8\xde\x1f\x00'
    _REDELEGATIONRESPONSE.fields_by_name['entries']._options = None
    _REDELEGATIONRESPONSE.fields_by_name['entries']._serialized_options = b'\xc8\xde\x1f\x00'
    _REDELEGATIONRESPONSE._options = None
    _REDELEGATIONRESPONSE._serialized_options = b'\xe8\xa0\x1f\x00'
    _POOL.fields_by_name['not_bonded_tokens']._options = None
    _POOL.fields_by_name['not_bonded_tokens']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xea\xde\x1f\x11not_bonded_tokens\xc8\xde\x1f\x00'
    _POOL.fields_by_name['bonded_tokens']._options = None
    _POOL.fields_by_name['bonded_tokens']._serialized_options = b'\xea\xde\x1f\rbonded_tokens\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"bonded_tokens"'
    _POOL._options = None
    _POOL._serialized_options = b'\xf0\xa0\x1f\x01\xe8\xa0\x1f\x01'
    _BONDSTATUS._serialized_start = 4759
    _BONDSTATUS._serialized_end = 4941
    _HISTORICALINFO._serialized_start = 267
    _HISTORICALINFO._serialized_end = 388
    _COMMISSIONRATES._serialized_start = 391
    _COMMISSIONRATES._serialized_end = 664
    _COMMISSION._serialized_start = 667
    _COMMISSION._serialized_end = 847
    _DESCRIPTION._serialized_start = 850
    _DESCRIPTION._serialized_end = 997
    _VALIDATOR._serialized_start = 1000
    _VALIDATOR._serialized_end = 1789
    _VALADDRESSES._serialized_start = 1791
    _VALADDRESSES._serialized_end = 1834
    _DVPAIR._serialized_start = 1837
    _DVPAIR._serialized_end = 1973
    _DVPAIRS._serialized_start = 1975
    _DVPAIRS._serialized_end = 2037
    _DVVTRIPLET._serialized_start = 2040
    _DVVTRIPLET._serialized_end = 2253
    _DVVTRIPLETS._serialized_start = 2255
    _DVVTRIPLETS._serialized_end = 2328
    _DELEGATION._serialized_start = 2331
    _DELEGATION._serialized_end = 2535
    _UNBONDINGDELEGATION._serialized_start = 2538
    _UNBONDINGDELEGATION._serialized_end = 2760
    _UNBONDINGDELEGATIONENTRY._serialized_start = 2763
    _UNBONDINGDELEGATIONENTRY._serialized_end = 3105
    _REDELEGATIONENTRY._serialized_start = 3108
    _REDELEGATIONENTRY._serialized_end = 3446
    _REDELEGATION._serialized_start = 3449
    _REDELEGATION._serialized_end = 3730
    _PARAMS._serialized_start = 3733
    _PARAMS._serialized_end = 4035
    _DELEGATIONRESPONSE._serialized_start = 4038
    _DELEGATIONRESPONSE._serialized_end = 4180
    _REDELEGATIONENTRYRESPONSE._serialized_start = 4183
    _REDELEGATIONENTRYRESPONSE._serialized_end = 4358
    _REDELEGATIONRESPONSE._serialized_start = 4361
    _REDELEGATIONRESPONSE._serialized_end = 4529
    _POOL._serialized_start = 4532
    _POOL._serialized_end = 4756




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class MsgSwapRequest(_message.Message):
    __slots__ = ['amount', 'frm', 'receiver', 'tx_hash']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    amount: str
    frm: str
    receiver: str
    tx_hash: bytes

    def __init__(self, frm: _Optional[str]=..., tx_hash: _Optional[bytes]=..., receiver: _Optional[str]=..., amount: _Optional[str]=...) -> None:
        ...

class MsgSwapResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class CustomHttpPattern(_message.Message):
    __slots__ = ['kind', 'path']
    KIND_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    kind: str
    path: str

    def __init__(self, kind: _Optional[str]=..., path: _Optional[str]=...) -> None:
        ...

class Http(_message.Message):
    __slots__ = ['fully_decode_reserved_expansion', 'rules']
    FULLY_DECODE_RESERVED_EXPANSION_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    fully_decode_reserved_expansion: bool
    rules: _containers.RepeatedCompositeFieldContainer[HttpRule]

    def __init__(self, rules: _Optional[_Iterable[_Union[(HttpRule, _Mapping)]]]=..., fully_decode_reserved_expansion: bool=...) -> None:
        ...

class HttpRule(_message.Message):
    __slots__ = ['additional_bindings', 'body', 'custom', 'delete', 'get', 'patch', 'post', 'put', 'response_body', 'selector']
    ADDITIONAL_BINDINGS_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    DELETE_FIELD_NUMBER: _ClassVar[int]
    GET_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    PUT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_BODY_FIELD_NUMBER: _ClassVar[int]
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    additional_bindings: _containers.RepeatedCompositeFieldContainer[HttpRule]
    body: str
    custom: CustomHttpPattern
    delete: str
    get: str
    patch: str
    post: str
    put: str
    response_body: str
    selector: str

    def __init__(self, selector: _Optional[str]=..., get: _Optional[str]=..., put: _Optional[str]=..., post: _Optional[str]=..., delete: _Optional[str]=..., patch: _Optional[str]=..., custom: _Optional[_Union[(CustomHttpPattern, _Mapping)]]=..., body: _Optional[str]=..., response_body: _Optional[str]=..., additional_bindings: _Optional[_Iterable[_Union[(HttpRule, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/crisis/v1beta1/genesis.proto\x12\x15cosmos.crisis.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\\\n\x0cGenesisState\x12L\n\x0cconstant_fee\x18\x03 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"constant_fee"B-Z+github.com/cosmos/cosmos-sdk/x/crisis/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/crisis/types'
    _GENESISSTATE.fields_by_name['constant_fee']._options = None
    _GENESISSTATE.fields_by_name['constant_fee']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"constant_fee"'
    _GENESISSTATE._serialized_start = 116
    _GENESISSTATE._serialized_end = 208




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/crypto/multisig/keys.proto\x12\x16cosmos.crypto.multisig\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto"\x8c\x01\n\x11LegacyAminoPubKey\x12\'\n\tthreshold\x18\x01 \x01(\rB\x14\xf2\xde\x1f\x10yaml:"threshold"\x12H\n\x0bpublic_keys\x18\x02 \x03(\x0b2\x14.google.protobuf.AnyB\x1d\xe2\xde\x1f\x07PubKeys\xf2\xde\x1f\x0eyaml:"pubkeys":\x04\x88\xa0\x1f\x00B3Z1github.com/cosmos/cosmos-sdk/crypto/keys/multisigb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.keys_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/crypto/keys/multisig'
    _LEGACYAMINOPUBKEY.fields_by_name['threshold']._options = None
    _LEGACYAMINOPUBKEY.fields_by_name['threshold']._serialized_options = b'\xf2\xde\x1f\x10yaml:"threshold"'
    _LEGACYAMINOPUBKEY.fields_by_name['public_keys']._options = None
    _LEGACYAMINOPUBKEY.fields_by_name['public_keys']._serialized_options = b'\xe2\xde\x1f\x07PubKeys\xf2\xde\x1f\x0eyaml:"pubkeys"'
    _LEGACYAMINOPUBKEY._options = None
    _LEGACYAMINOPUBKEY._serialized_options = b'\x88\xa0\x1f\x00'
    _LEGACYAMINOPUBKEY._serialized_start = 111
    _LEGACYAMINOPUBKEY._serialized_end = 251




from tendermint.types import block_pb2 as _block_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class BlockRequest(_message.Message):
    __slots__ = ['height']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int

    def __init__(self, height: _Optional[int]=...) -> None:
        ...

class BlockResponse(_message.Message):
    __slots__ = ['block']
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    block: _block_pb2.Block

    def __init__(self, block: _Optional[_Union[(_block_pb2.Block, _Mapping)]]=...) -> None:
        ...

class Message(_message.Message):
    __slots__ = ['block_request', 'block_response', 'no_block_response', 'status_request', 'status_response']
    BLOCK_REQUEST_FIELD_NUMBER: _ClassVar[int]
    BLOCK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    NO_BLOCK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    STATUS_REQUEST_FIELD_NUMBER: _ClassVar[int]
    STATUS_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    block_request: BlockRequest
    block_response: BlockResponse
    no_block_response: NoBlockResponse
    status_request: StatusRequest
    status_response: StatusResponse

    def __init__(self, block_request: _Optional[_Union[(BlockRequest, _Mapping)]]=..., no_block_response: _Optional[_Union[(NoBlockResponse, _Mapping)]]=..., block_response: _Optional[_Union[(BlockResponse, _Mapping)]]=..., status_request: _Optional[_Union[(StatusRequest, _Mapping)]]=..., status_response: _Optional[_Union[(StatusResponse, _Mapping)]]=...) -> None:
        ...

class NoBlockResponse(_message.Message):
    __slots__ = ['height']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int

    def __init__(self, height: _Optional[int]=...) -> None:
        ...

class StatusRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class StatusResponse(_message.Message):
    __slots__ = ['base', 'height']
    BASE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    base: int
    height: int

    def __init__(self, height: _Optional[int]=..., base: _Optional[int]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/feegrant/v1beta1/tx.proto\x12\x17cosmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19cosmos_proto/cosmos.proto"q\n\x11MsgGrantAllowance\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12:\n\tallowance\x18\x03 \x01(\x0b2\x14.google.protobuf.AnyB\x11\xca\xb4-\rFeeAllowanceI"\x1b\n\x19MsgGrantAllowanceResponse"6\n\x12MsgRevokeAllowance\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t"\x1c\n\x1aMsgRevokeAllowanceResponse2\xec\x01\n\x03Msg\x12p\n\x0eGrantAllowance\x12*.cosmos.feegrant.v1beta1.MsgGrantAllowance\x1a2.cosmos.feegrant.v1beta1.MsgGrantAllowanceResponse\x12s\n\x0fRevokeAllowance\x12+.cosmos.feegrant.v1beta1.MsgRevokeAllowance\x1a3.cosmos.feegrant.v1beta1.MsgRevokeAllowanceResponseB)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z'github.com/cosmos/cosmos-sdk/x/feegrant"
    _MSGGRANTALLOWANCE.fields_by_name['allowance']._options = None
    _MSGGRANTALLOWANCE.fields_by_name['allowance']._serialized_options = b'\xca\xb4-\rFeeAllowanceI'
    _MSGGRANTALLOWANCE._serialized_start = 137
    _MSGGRANTALLOWANCE._serialized_end = 250
    _MSGGRANTALLOWANCERESPONSE._serialized_start = 252
    _MSGGRANTALLOWANCERESPONSE._serialized_end = 279
    _MSGREVOKEALLOWANCE._serialized_start = 281
    _MSGREVOKEALLOWANCE._serialized_end = 335
    _MSGREVOKEALLOWANCERESPONSE._serialized_start = 337
    _MSGREVOKEALLOWANCERESPONSE._serialized_end = 365
    _MSG._serialized_start = 368
    _MSG._serialized_end = 604




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/staking/v1beta1/authz.proto\x12\x16cosmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\x90\x03\n\x12StakeAuthorization\x12Z\n\nmax_tokens\x18\x01 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB+\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\x12K\n\nallow_list\x18\x02 \x01(\x0b25.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsH\x00\x12J\n\tdeny_list\x18\x03 \x01(\x0b25.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsH\x00\x12E\n\x12authorization_type\x18\x04 \x01(\x0e2).cosmos.staking.v1beta1.AuthorizationType\x1a\x1d\n\nValidators\x12\x0f\n\x07address\x18\x01 \x03(\t:\x11\xca\xb4-\rAuthorizationB\x0c\n\nvalidators*\x9e\x01\n\x11AuthorizationType\x12"\n\x1eAUTHORIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bAUTHORIZATION_TYPE_DELEGATE\x10\x01\x12!\n\x1dAUTHORIZATION_TYPE_UNDELEGATE\x10\x02\x12!\n\x1dAUTHORIZATION_TYPE_REDELEGATE\x10\x03B.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.authz_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
    _STAKEAUTHORIZATION.fields_by_name['max_tokens']._options = None
    _STAKEAUTHORIZATION.fields_by_name['max_tokens']._serialized_options = b"\xaa\xdf\x1f'github.com/cosmos/cosmos-sdk/types.Coin"
    _STAKEAUTHORIZATION._options = None
    _STAKEAUTHORIZATION._serialized_options = b'\xca\xb4-\rAuthorization'
    _AUTHORIZATIONTYPE._serialized_start = 547
    _AUTHORIZATIONTYPE._serialized_end = 705
    _STAKEAUTHORIZATION._serialized_start = 144
    _STAKEAUTHORIZATION._serialized_end = 544
    _STAKEAUTHORIZATION_VALIDATORS._serialized_start = 482
    _STAKEAUTHORIZATION_VALIDATORS._serialized_end = 511




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ['allow_messages', 'host_enabled']
    ALLOW_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    HOST_ENABLED_FIELD_NUMBER: _ClassVar[int]
    allow_messages: _containers.RepeatedScalarFieldContainer[str]
    host_enabled: bool

    def __init__(self, host_enabled: bool=..., allow_messages: _Optional[_Iterable[str]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgRegisterRequest(_message.Message):
    __slots__ = ['description', 'frm', 'identity', 'name', 'website']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    description: str
    frm: str
    identity: str
    name: str
    website: str

    def __init__(self, frm: _Optional[str]=..., name: _Optional[str]=..., identity: _Optional[str]=..., website: _Optional[str]=..., description: _Optional[str]=...) -> None:
        ...

class MsgRegisterResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpdateRequest(_message.Message):
    __slots__ = ['description', 'frm', 'identity', 'name', 'status', 'website']
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    description: str
    frm: str
    identity: str
    name: str
    status: _status_pb2.Status
    website: str

    def __init__(self, frm: _Optional[str]=..., name: _Optional[str]=..., identity: _Optional[str]=..., website: _Optional[str]=..., description: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=...) -> None:
        ...

class MsgUpdateResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sentinel/subscription/v2/events.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto"\xc6\x01\n\x11EventUpdateStatus\x12<\n\x06status\x18\x01 \x01(\x0e2\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:"status"\x12#\n\x07address\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"\x12-\n\x07plan_id\x18\x04 \x01(\x04B\x1c\xe2\xde\x1f\x06PlanID\xf2\xde\x1f\x0eyaml:"plan_id""\xe4\x01\n\rEventAllocate\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12E\n\rgranted_bytes\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12F\n\x0eutilised_bytes\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x1f\n\x02id\x18\x04 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\x88\x01\n\x11EventCreatePayout\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"node_address"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\xe0\x01\n\x11EventPayForPayout\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"node_address"\x12#\n\x07payment\x18\x03 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"payment"\x121\n\x0estaking_reward\x18\x04 \x01(\tB\x19\xf2\xde\x1f\x15yaml:"staking_reward"\x12\x1f\n\x02id\x18\x05 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\xe6\x01\n\x0fEventPayForPlan\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12#\n\x07payment\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"payment"\x125\n\x10provider_address\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"provider_address"\x121\n\x0estaking_reward\x18\x04 \x01(\tB\x19\xf2\xde\x1f\x15yaml:"staking_reward"\x12\x1f\n\x02id\x18\x05 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id""\xbf\x02\n\x12EventPayForSession\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"node_address"\x12#\n\x07payment\x18\x03 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"payment"\x121\n\x0estaking_reward\x18\x04 \x01(\tB\x19\xf2\xde\x1f\x15yaml:"staking_reward"\x126\n\nsession_id\x18\x05 \x01(\x04B"\xe2\xde\x1f\tSessionID\xf2\xde\x1f\x11yaml:"session_id"\x12E\n\x0fsubscription_id\x18\x06 \x01(\x04B,\xe2\xde\x1f\x0eSubscriptionID\xf2\xde\x1f\x16yaml:"subscription_id""v\n\x0bEventRefund\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12!\n\x06amount\x18\x02 \x01(\tB\x11\xf2\xde\x1f\ryaml:"amount"\x12\x1f\n\x02id\x18\x03 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _EVENTUPDATESTATUS.fields_by_name['status']._options = None
    _EVENTUPDATESTATUS.fields_by_name['status']._serialized_options = b'\xf2\xde\x1f\ryaml:"status"'
    _EVENTUPDATESTATUS.fields_by_name['address']._options = None
    _EVENTUPDATESTATUS.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUPDATESTATUS.fields_by_name['id']._options = None
    _EVENTUPDATESTATUS.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTUPDATESTATUS.fields_by_name['plan_id']._options = None
    _EVENTUPDATESTATUS.fields_by_name['plan_id']._serialized_options = b'\xe2\xde\x1f\x06PlanID\xf2\xde\x1f\x0eyaml:"plan_id"'
    _EVENTALLOCATE.fields_by_name['address']._options = None
    _EVENTALLOCATE.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTALLOCATE.fields_by_name['granted_bytes']._options = None
    _EVENTALLOCATE.fields_by_name['granted_bytes']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _EVENTALLOCATE.fields_by_name['utilised_bytes']._options = None
    _EVENTALLOCATE.fields_by_name['utilised_bytes']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _EVENTALLOCATE.fields_by_name['id']._options = None
    _EVENTALLOCATE.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTCREATEPAYOUT.fields_by_name['address']._options = None
    _EVENTCREATEPAYOUT.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTCREATEPAYOUT.fields_by_name['node_address']._options = None
    _EVENTCREATEPAYOUT.fields_by_name['node_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"node_address"'
    _EVENTCREATEPAYOUT.fields_by_name['id']._options = None
    _EVENTCREATEPAYOUT.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTPAYFORPAYOUT.fields_by_name['address']._options = None
    _EVENTPAYFORPAYOUT.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTPAYFORPAYOUT.fields_by_name['node_address']._options = None
    _EVENTPAYFORPAYOUT.fields_by_name['node_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"node_address"'
    _EVENTPAYFORPAYOUT.fields_by_name['payment']._options = None
    _EVENTPAYFORPAYOUT.fields_by_name['payment']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"payment"'
    _EVENTPAYFORPAYOUT.fields_by_name['staking_reward']._options = None
    _EVENTPAYFORPAYOUT.fields_by_name['staking_reward']._serialized_options = b'\xf2\xde\x1f\x15yaml:"staking_reward"'
    _EVENTPAYFORPAYOUT.fields_by_name['id']._options = None
    _EVENTPAYFORPAYOUT.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTPAYFORPLAN.fields_by_name['address']._options = None
    _EVENTPAYFORPLAN.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTPAYFORPLAN.fields_by_name['payment']._options = None
    _EVENTPAYFORPLAN.fields_by_name['payment']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"payment"'
    _EVENTPAYFORPLAN.fields_by_name['provider_address']._options = None
    _EVENTPAYFORPLAN.fields_by_name['provider_address']._serialized_options = b'\xf2\xde\x1f\x17yaml:"provider_address"'
    _EVENTPAYFORPLAN.fields_by_name['staking_reward']._options = None
    _EVENTPAYFORPLAN.fields_by_name['staking_reward']._serialized_options = b'\xf2\xde\x1f\x15yaml:"staking_reward"'
    _EVENTPAYFORPLAN.fields_by_name['id']._options = None
    _EVENTPAYFORPLAN.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTPAYFORSESSION.fields_by_name['address']._options = None
    _EVENTPAYFORSESSION.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTPAYFORSESSION.fields_by_name['node_address']._options = None
    _EVENTPAYFORSESSION.fields_by_name['node_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"node_address"'
    _EVENTPAYFORSESSION.fields_by_name['payment']._options = None
    _EVENTPAYFORSESSION.fields_by_name['payment']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"payment"'
    _EVENTPAYFORSESSION.fields_by_name['staking_reward']._options = None
    _EVENTPAYFORSESSION.fields_by_name['staking_reward']._serialized_options = b'\xf2\xde\x1f\x15yaml:"staking_reward"'
    _EVENTPAYFORSESSION.fields_by_name['session_id']._options = None
    _EVENTPAYFORSESSION.fields_by_name['session_id']._serialized_options = b'\xe2\xde\x1f\tSessionID\xf2\xde\x1f\x11yaml:"session_id"'
    _EVENTPAYFORSESSION.fields_by_name['subscription_id']._options = None
    _EVENTPAYFORSESSION.fields_by_name['subscription_id']._serialized_options = b'\xe2\xde\x1f\x0eSubscriptionID\xf2\xde\x1f\x16yaml:"subscription_id"'
    _EVENTREFUND.fields_by_name['address']._options = None
    _EVENTREFUND.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTREFUND.fields_by_name['amount']._options = None
    _EVENTREFUND.fields_by_name['amount']._serialized_options = b'\xf2\xde\x1f\ryaml:"amount"'
    _EVENTREFUND.fields_by_name['id']._options = None
    _EVENTREFUND.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTUPDATESTATUS._serialized_start = 122
    _EVENTUPDATESTATUS._serialized_end = 320
    _EVENTALLOCATE._serialized_start = 323
    _EVENTALLOCATE._serialized_end = 551
    _EVENTCREATEPAYOUT._serialized_start = 554
    _EVENTCREATEPAYOUT._serialized_end = 690
    _EVENTPAYFORPAYOUT._serialized_start = 693
    _EVENTPAYFORPAYOUT._serialized_end = 917
    _EVENTPAYFORPLAN._serialized_start = 920
    _EVENTPAYFORPLAN._serialized_end = 1150
    _EVENTPAYFORSESSION._serialized_start = 1153
    _EVENTPAYFORSESSION._serialized_end = 1472
    _EVENTREFUND._serialized_start = 1474
    _EVENTREFUND._serialized_end = 1592




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Inflation(_message.Message):
    __slots__ = ['max', 'min', 'rate_change', 'timestamp']
    MAX_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    RATE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    max: str
    min: str
    rate_change: str
    timestamp: _timestamp_pb2.Timestamp

    def __init__(self, max: _Optional[str]=..., min: _Optional[str]=..., rate_change: _Optional[str]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ['denom', 'deposit', 'expiry', 'free', 'id', 'node', 'owner', 'plan', 'price', 'status', 'status_at']
    DENOM_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    FREE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    denom: str
    deposit: _coin_pb2.Coin
    expiry: _timestamp_pb2.Timestamp
    free: str
    id: int
    node: str
    owner: str
    plan: int
    price: _coin_pb2.Coin
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp

    def __init__(self, id: _Optional[int]=..., owner: _Optional[str]=..., node: _Optional[str]=..., price: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=..., deposit: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=..., plan: _Optional[int]=..., denom: _Optional[str]=..., expiry: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., free: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., status_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/event.proto\x12\x14cosmos.authz.v1beta1"D\n\nEventGrant\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12\x0f\n\x07granter\x18\x03 \x01(\t\x12\x0f\n\x07grantee\x18\x04 \x01(\t"E\n\x0bEventRevoke\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12\x0f\n\x07granter\x18\x03 \x01(\t\x12\x0f\n\x07grantee\x18\x04 \x01(\tB&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.event_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
    _EVENTGRANT._serialized_start = 58
    _EVENTGRANT._serialized_end = 126
    _EVENTREVOKE._serialized_start = 128
    _EVENTREVOKE._serialized_end = 197




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/crypto/secp256k1/keys.proto\x12\x17cosmos.crypto.secp256k1\x1a\x14gogoproto/gogo.proto"\x1b\n\x06PubKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c:\x04\x98\xa0\x1f\x00"\x16\n\x07PrivKey\x12\x0b\n\x03key\x18\x01 \x01(\x0cB4Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.secp256k1.keys_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1'
    _PUBKEY._options = None
    _PUBKEY._serialized_options = b'\x98\xa0\x1f\x00'
    _PUBKEY._serialized_start = 85
    _PUBKEY._serialized_end = 112
    _PRIVKEY._serialized_start = 114
    _PRIVKEY._serialized_end = 136




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....sentinel.session.v2 import querier_pb2 as sentinel_dot_session_dot_v2_dot_querier__pb2

class QueryServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.QuerySessions = channel.unary_unary('/sentinel.session.v2.QueryService/QuerySessions', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsResponse.FromString)
        self.QuerySessionsForAccount = channel.unary_unary('/sentinel.session.v2.QueryService/QuerySessionsForAccount', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAccountRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAccountResponse.FromString)
        self.QuerySessionsForNode = channel.unary_unary('/sentinel.session.v2.QueryService/QuerySessionsForNode', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForNodeRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForNodeResponse.FromString)
        self.QuerySessionsForSubscription = channel.unary_unary('/sentinel.session.v2.QueryService/QuerySessionsForSubscription', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForSubscriptionRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForSubscriptionResponse.FromString)
        self.QuerySessionsForAllocation = channel.unary_unary('/sentinel.session.v2.QueryService/QuerySessionsForAllocation', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAllocationRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAllocationResponse.FromString)
        self.QuerySession = channel.unary_unary('/sentinel.session.v2.QueryService/QuerySession', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionResponse.FromString)
        self.QueryParams = channel.unary_unary('/sentinel.session.v2.QueryService/QueryParams', request_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QueryParamsRequest.SerializeToString, response_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QueryParamsResponse.FromString)

class QueryServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def QuerySessions(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySessionsForAccount(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySessionsForNode(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySessionsForSubscription(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySessionsForAllocation(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerySession(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryParams(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'QuerySessions': grpc.unary_unary_rpc_method_handler(servicer.QuerySessions, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsResponse.SerializeToString), 'QuerySessionsForAccount': grpc.unary_unary_rpc_method_handler(servicer.QuerySessionsForAccount, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAccountRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAccountResponse.SerializeToString), 'QuerySessionsForNode': grpc.unary_unary_rpc_method_handler(servicer.QuerySessionsForNode, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForNodeRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForNodeResponse.SerializeToString), 'QuerySessionsForSubscription': grpc.unary_unary_rpc_method_handler(servicer.QuerySessionsForSubscription, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForSubscriptionRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForSubscriptionResponse.SerializeToString), 'QuerySessionsForAllocation': grpc.unary_unary_rpc_method_handler(servicer.QuerySessionsForAllocation, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAllocationRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAllocationResponse.SerializeToString), 'QuerySession': grpc.unary_unary_rpc_method_handler(servicer.QuerySession, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionResponse.SerializeToString), 'QueryParams': grpc.unary_unary_rpc_method_handler(servicer.QueryParams, request_deserializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QueryParamsRequest.FromString, response_serializer=sentinel_dot_session_dot_v2_dot_querier__pb2.QueryParamsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('sentinel.session.v2.QueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class QueryService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def QuerySessions(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QuerySessions', sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySessionsForAccount(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QuerySessionsForAccount', sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAccountRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAccountResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySessionsForNode(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QuerySessionsForNode', sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForNodeRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForNodeResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySessionsForSubscription(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QuerySessionsForSubscription', sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForSubscriptionRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForSubscriptionResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySessionsForAllocation(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QuerySessionsForAllocation', sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAllocationRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionsForAllocationResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerySession(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QuerySession', sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QuerySessionResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryParams(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sentinel.session.v2.QueryService/QueryParams', sentinel_dot_session_dot_v2_dot_querier__pb2.QueryParamsRequest.SerializeToString, sentinel_dot_session_dot_v2_dot_querier__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.swap.v1 import swap_pb2 as _swap_pb2
from sentinel.swap.v1 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params

    def __init__(self, params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...

class QuerySwapRequest(_message.Message):
    __slots__ = ['tx_hash']
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    tx_hash: bytes

    def __init__(self, tx_hash: _Optional[bytes]=...) -> None:
        ...

class QuerySwapResponse(_message.Message):
    __slots__ = ['swap']
    SWAP_FIELD_NUMBER: _ClassVar[int]
    swap: _swap_pb2.Swap

    def __init__(self, swap: _Optional[_Union[(_swap_pb2.Swap, _Mapping)]]=...) -> None:
        ...

class QuerySwapsRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySwapsResponse(_message.Message):
    __slots__ = ['pagination', 'swaps']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SWAPS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    swaps: _containers.RepeatedCompositeFieldContainer[_swap_pb2.Swap]

    def __init__(self, swaps: _Optional[_Iterable[_Union[(_swap_pb2.Swap, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/node/v2/params.proto\x12\x10sentinel.node.v2\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto"\xeb\x05\n\x06Params\x120\n\x07deposit\x18\x01 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12<\n\x0factive_duration\x18\x02 \x01(\x0b2\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12h\n\x13max_gigabyte_prices\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12h\n\x13min_gigabyte_prices\x18\x04 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12f\n\x11max_hourly_prices\x18\x05 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12f\n\x11min_hourly_prices\x18\x06 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12"\n\x1amax_subscription_gigabytes\x18\x07 \x01(\x03\x12"\n\x1amin_subscription_gigabytes\x18\x08 \x01(\x03\x12\x1e\n\x16max_subscription_hours\x18\t \x01(\x03\x12\x1e\n\x16min_subscription_hours\x18\n \x01(\x03\x12E\n\rstaking_share\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00B7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.params_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _PARAMS.fields_by_name['deposit']._options = None
    _PARAMS.fields_by_name['deposit']._serialized_options = b'\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['active_duration']._options = None
    _PARAMS.fields_by_name['active_duration']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01'
    _PARAMS.fields_by_name['max_gigabyte_prices']._options = None
    _PARAMS.fields_by_name['max_gigabyte_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PARAMS.fields_by_name['min_gigabyte_prices']._options = None
    _PARAMS.fields_by_name['min_gigabyte_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PARAMS.fields_by_name['max_hourly_prices']._options = None
    _PARAMS.fields_by_name['max_hourly_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PARAMS.fields_by_name['min_hourly_prices']._options = None
    _PARAMS.fields_by_name['min_hourly_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PARAMS.fields_by_name['staking_share']._options = None
    _PARAMS.fields_by_name['staking_share']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS._serialized_start = 138
    _PARAMS._serialized_end = 885




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.api import annotations_pb2 as _annotations_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryClientParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryClientParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _client_pb2.Params

    def __init__(self, params: _Optional[_Union[(_client_pb2.Params, _Mapping)]]=...) -> None:
        ...

class QueryClientStateRequest(_message.Message):
    __slots__ = ['client_id']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str

    def __init__(self, client_id: _Optional[str]=...) -> None:
        ...

class QueryClientStateResponse(_message.Message):
    __slots__ = ['client_state', 'proof', 'proof_height']
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    client_state: _any_pb2.Any
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryClientStatesRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryClientStatesResponse(_message.Message):
    __slots__ = ['client_states', 'pagination']
    CLIENT_STATES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    client_states: _containers.RepeatedCompositeFieldContainer[_client_pb2.IdentifiedClientState]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, client_states: _Optional[_Iterable[_Union[(_client_pb2.IdentifiedClientState, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryClientStatusRequest(_message.Message):
    __slots__ = ['client_id']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str

    def __init__(self, client_id: _Optional[str]=...) -> None:
        ...

class QueryClientStatusResponse(_message.Message):
    __slots__ = ['status']
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str

    def __init__(self, status: _Optional[str]=...) -> None:
        ...

class QueryConsensusStateRequest(_message.Message):
    __slots__ = ['client_id', 'latest_height', 'revision_height', 'revision_number']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    LATEST_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    latest_height: bool
    revision_height: int
    revision_number: int

    def __init__(self, client_id: _Optional[str]=..., revision_number: _Optional[int]=..., revision_height: _Optional[int]=..., latest_height: bool=...) -> None:
        ...

class QueryConsensusStateResponse(_message.Message):
    __slots__ = ['consensus_state', 'proof', 'proof_height']
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    consensus_state: _any_pb2.Any
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, consensus_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryConsensusStatesRequest(_message.Message):
    __slots__ = ['client_id', 'pagination']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, client_id: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryConsensusStatesResponse(_message.Message):
    __slots__ = ['consensus_states', 'pagination']
    CONSENSUS_STATES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    consensus_states: _containers.RepeatedCompositeFieldContainer[_client_pb2.ConsensusStateWithHeight]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, consensus_states: _Optional[_Iterable[_Union[(_client_pb2.ConsensusStateWithHeight, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryUpgradedClientStateRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryUpgradedClientStateResponse(_message.Message):
    __slots__ = ['upgraded_client_state']
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    upgraded_client_state: _any_pb2.Any

    def __init__(self, upgraded_client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class QueryUpgradedConsensusStateRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryUpgradedConsensusStateResponse(_message.Message):
    __slots__ = ['upgraded_consensus_state']
    UPGRADED_CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    upgraded_consensus_state: _any_pb2.Any

    def __init__(self, upgraded_consensus_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.mint.v1 import inflation_pb2 as sentinel_dot_mint_dot_v1_dot_inflation__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/mint/v1/genesis.proto\x12\x10sentinel.mint.v1\x1a\x14gogoproto/gogo.proto\x1a sentinel/mint/v1/inflation.proto"Z\n\x0cGenesisState\x12J\n\ninflations\x18\x01 \x03(\x0b2\x1b.sentinel.mint.v1.InflationB\x19\xf2\xde\x1f\x11yaml:"inflations"\xc8\xde\x1f\x00B7Z-github.com/sentinel-official/hub/x/mint/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.mint.v1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/mint/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _GENESISSTATE.fields_by_name['inflations']._options = None
    _GENESISSTATE.fields_by_name['inflations']._serialized_options = b'\xf2\xde\x1f\x11yaml:"inflations"\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 108
    _GENESISSTATE._serialized_end = 198




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.deposit.v1 import deposit_pb2 as sentinel_dot_deposit_dot_v1_dot_deposit__pb2
from ....sentinel.node.v2 import genesis_pb2 as sentinel_dot_node_dot_v2_dot_genesis__pb2
from ....sentinel.plan.v2 import genesis_pb2 as sentinel_dot_plan_dot_v2_dot_genesis__pb2
from ....sentinel.provider.v2 import genesis_pb2 as sentinel_dot_provider_dot_v2_dot_genesis__pb2
from ....sentinel.session.v2 import genesis_pb2 as sentinel_dot_session_dot_v2_dot_genesis__pb2
from ....sentinel.subscription.v2 import genesis_pb2 as sentinel_dot_subscription_dot_v2_dot_genesis__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/vpn/v1/genesis.proto\x12\x0fsentinel.vpn.v1\x1a\x14gogoproto/gogo.proto\x1a!sentinel/deposit/v1/deposit.proto\x1a\x1esentinel/node/v2/genesis.proto\x1a\x1esentinel/plan/v2/genesis.proto\x1a"sentinel/provider/v2/genesis.proto\x1a!sentinel/session/v2/genesis.proto\x1a&sentinel/subscription/v2/genesis.proto"\xd2\x02\n\x0cGenesisState\x124\n\x08deposits\x18\x01 \x03(\x0b2\x1c.sentinel.deposit.v1.DepositB\x04\xc8\xde\x1f\x00\x12-\n\x05nodes\x18\x02 \x01(\x0b2\x1e.sentinel.node.v2.GenesisState\x122\n\x05plans\x18\x03 \x03(\x0b2\x1d.sentinel.plan.v2.GenesisPlanB\x04\xc8\xde\x1f\x00\x125\n\tproviders\x18\x04 \x01(\x0b2".sentinel.provider.v2.GenesisState\x123\n\x08sessions\x18\x05 \x01(\x0b2!.sentinel.session.v2.GenesisState\x12=\n\rsubscriptions\x18\x06 \x01(\x0b2&.sentinel.subscription.v2.GenesisStateB6Z,github.com/sentinel-official/hub/x/vpn/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.vpn.v1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/sentinel-official/hub/x/vpn/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _GENESISSTATE.fields_by_name['deposits']._options = None
    _GENESISSTATE.fields_by_name['deposits']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['plans']._options = None
    _GENESISSTATE.fields_by_name['plans']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 283
    _GENESISSTATE._serialized_end = 621
